##############################################
####Phyllium locomotion MS - CFD##############
##############################################

library(readxl)
data<- read_excel("Phyllium_CFD.xlsx")

####Scaling relationships
#Lift to drag ratio
m<-lm(data$"L/D"~data$body_length+data$body_AR)
summary(m)
anova(m)

library(ggplot2)
p<-ggplot(data = data, mapping = aes(y =data$"L/D", x = data$body_AR, colour=as.factor(data$length_number))) +
  geom_point(size=2)+
  geom_line(size=0.5)+
  labs(y="Lift / Drag", x="Body AR")+
  theme(axis.line = element_line(colour = "black"))+
  guides(color=FALSE)+
  theme_bw(base_size = 10)+
  scale_color_manual(values=c("black", "red", "blue", "orange", "dodgerblue"))

library(cowplot)
plot_grid(p, p, labels = c('A', 'B'), ncol=1)

#Drag and lift coefficient
m<-lm(Cd~body_length+body_AR, data)
summary(m)
anova(m)

m<-lm(Cl~body_length+body_AR, data)
summary(m)
anova(m)

library(ggplot2)
ggplot(data)+
  geom_point(size=2, aes(y = data$Cd, x = data$body_AR, colour=as.factor(data$length_number)))+
  geom_line(size=0.5, aes(y = data$Cd, x = data$body_AR, colour=as.factor(data$length_number)))+
  geom_point(size=2, aes(y = data$Cl, x = data$body_AR, colour=as.factor(data$length_number)))+
  geom_line(size=0.5, aes(y = data$Cl, x = data$body_AR, colour=as.factor(data$length_number)))+
  labs(y="Drag or lift coefficient", x="Body AR")+
  theme(axis.line = element_line(colour = "black"))+
  theme_bw(base_size = 10)+
  scale_color_manual(values=c("black", "red", "blue", "orange", "dodgerblue"))

library(ggplot2)
pd<-ggplot(data)+
  geom_point(size=2, aes(y = data$Cd, x = data$body_AR, colour=as.factor(data$length_number)))+
  geom_line(size=0.5, aes(y = data$Cd, x = data$body_AR, colour=as.factor(data$length_number)))+
  labs(y="Drag coefficient Cd", x="Body AR")+
  theme(axis.line = element_line(colour = "black"))+
  theme_bw(base_size = 10)+
  guides(color=FALSE)+
  scale_color_manual(values=c("black", "red", "blue", "orange", "dodgerblue"))

pl<-ggplot(data)+
  geom_point(size=2, aes(y = Cl, x = body_AR, colour=as.factor(length_number)))+
  geom_line(size=0.5, aes(y = Cl, x = body_AR, colour=as.factor(length_number)))+
  labs(y="Lift coefficient Cl", x="Body AR")+
  theme(axis.line = element_line(colour = "black"))+
  guides(color=FALSE)+
  theme_bw(base_size = 10)+
  scale_color_manual(values=c("black", "red", "blue", "orange", "dodgerblue"))

library(cowplot)
plot_grid(pd, pl, labels = c('A', 'B'), ncol=1)


#####Express lift and drag as percentage of body weight

data$relative_drag<-(data$body_drag/data$weight)*100
data$relative_lift<-(data$body_lift/data$weight)*100

m<-lm(relative_drag~body_length+body_AR, data)
summary(m)
anova(m)

m<-lm(relative_lift~body_length+body_AR, data)
summary(m)
anova(m)

library(ggplot2)
ggplot(data = data) +
  geom_point(mapping = aes(y = relative_drag, x = body_AR, colour=as.factor(length_number)), size=2)+
  geom_line(mapping = aes(y = relative_drag, x = body_AR, colour=as.factor(length_number)), size=0.5, linetype="solid")+
  geom_point(mapping = aes(y = relative_lift, x = body_AR, colour=as.factor(length_number)), size=2)+
  geom_line(mapping = aes(y = relative_lift, x = body_AR, colour=as.factor(length_number)), size=0.5, linetype="dashed")+
  labs(y="Relative aerodynamic force (% of body weight)", x="Body aspect ratio")+
  theme(axis.line = element_line(colour = "black"))+
  theme_bw(base_size = 10)+
  guides(color=FALSE)+
  scale_color_manual(values=c("black", "red", "blue", "orange", "dodgerblue"))