#################################################################
##Phyllium locomotion MS - Morphological scaling relationships###
#################################################################

se <- function(x) sd(x, na.rm=TRUE)/sqrt(length(x))#standard error function

library(readxl)
library(ggplot2)
data<- read_excel("Phyllium_measurements.xlsx")
datamale<-subset(data, data$sex=="M")
datafemale<-subset(data, data$sex=="F")

#######Sexual dimorphism: compare male and female means for different morphological traits
#Body mass
ggplot(data, aes(x = body_mass_mg/1000, fill=as.factor(sex))) + geom_histogram(size=1, bins=30) + scale_x_continuous(breaks=pretty(data$body_mass_mg/1000, n = 10))+ theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),panel.background = element_blank(), axis.line = element_line(colour = "black"))
mean(datamale$body_mass_mg)
se(datamale$body_mass_mg)
mean(datafemale$body_mass_mg)
se(datafemale$body_mass_mg)
wilcox.test(body_mass_mg~as.factor(sex), data=data)

#Body length
ggplot(data, aes(x = body_length, fill=as.factor(sex))) + geom_histogram(size=1, bins=30) + scale_x_continuous(breaks=pretty(data$body_length, n = 10)) + theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),panel.background = element_blank(), axis.line = element_line(colour = "black"))
mean(datamale$body_length)
se(datamale$body_length)
mean(datafemale$body_length)
se(datafemale$body_length)
wilcox.test(body_length~as.factor(sex), data=data)

#Aspect ratio
ggplot(data, aes(x = body_AR, fill=as.factor(sex))) + geom_histogram(size=1, bins=28) +scale_x_continuous(breaks=pretty(data$body_AR, n = 5))+ theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),panel.background = element_blank(), axis.line = element_line(colour = "black"))
mean(datamale$body_AR)
se(datamale$body_AR)
mean(datafemale$body_AR)
se(datafemale$body_AR)
wilcox.test(body_AR~as.factor(sex), data=data)

#Antenna length
ggplot(data, aes(x = antenna_length, fill=as.factor(sex))) + geom_histogram(size=1, bins=30) +scale_x_continuous(breaks=pretty(data$antenna_length, n = 5))+ theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),panel.background = element_blank(), axis.line = element_line(colour = "black"))
mean(datamale$antenna_length, na.rm=TRUE)
se(datamale$antenna_length)
mean(datafemale$antenna_length, na.rm=TRUE)
se(datafemale$antenna_length)
wilcox.test(antenna_length~as.factor(sex), data=data)


#######Scaling relationships
##Body mass - body length  (also used for CFD)

m<-lm(log10(data$body_mass_mg)~log10(data$body_length)*as.factor(data$sex))
summary(m)
anova(m)
confint(m)

#males
ggplot(datamale,aes(x=log10(body_length),y=log10(body_mass_mg),color=as.factor(sex), na.rm = TRUE)) +
  geom_point(size=1)+
  stat_smooth(method = "lm")+
  geom_abline(slope=3, intercept=-2.5)+
  scale_color_manual(values=c("blue"))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"))

#females
ggplot(datafemale,aes(x=log10(body_length),y=log10(body_mass_mg),color=as.factor(sex), na.rm = TRUE)) +
  geom_point(size=1)+
  stat_smooth(method = "lm")+
  geom_abline(slope=3, intercept=-2.05)+
  scale_color_manual(values=c("red"))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"))


##Body area - body length
m<-lm(log10(data$body_area)~log10(data$body_length)*as.factor(data$sex))
summary(m)
anova(m)
confint(m)

#males
ggplot(datamale,aes(x=log10(body_length),y=log10(body_area),color=as.factor(sex), na.rm = TRUE)) +
  geom_point(size=1)+
  stat_smooth(method = "lm")+
  geom_abline(slope=2, intercept=-0.9)+
  scale_color_manual(values=c("blue"))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"))

#females
ggplot(datafemale,aes(x=log10(body_length),y=log10(body_area),color=as.factor(sex), na.rm = TRUE)) +
  geom_point(size=1)+
  stat_smooth(method = "lm")+
  geom_abline(slope=2, intercept=-0.62)+
  scale_color_manual(values=c("red"))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"))

                                                                                                 panel.background = element_blank(), axis.line = element_blank())
##Body circularity - body length
m<-lm(log10(body_circularity)~sex*log10(body_length), data=data)
summary(m)
anova(m)
confint(m)

#males
ggplot(datamale,aes(x=log10(body_length),y=log10(body_circularity),color=as.factor(sex), na.rm = TRUE)) +
  geom_point(size=1)+
  #stat_smooth(method = "lm")+
  geom_abline(slope=0, intercept=-0.48)+
  scale_color_manual(values=c("blue"))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"))

#females
ggplot(datafemale,aes(x=log10(body_length),y=log10(body_circularity),color=as.factor(sex), na.rm = TRUE)) +
  geom_point(size=1)+
  #stat_smooth(method = "lm")+
  geom_abline(slope=0, intercept=-0.26)+
  scale_color_manual(values=c("red"))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"))

##Body AR - body length
m<-lm(log10(body_AR)~sex*log10(body_length), data=data)
summary(m)
anova(m)
confint(m)

#males
ggplot(datamale,aes(x=log10(body_length),y=log10(body_AR),color=as.factor(sex), na.rm = TRUE)) +
  geom_point(size=1)+
  #stat_smooth(method = "lm")+
  geom_abline(slope=0, intercept=0.75)+
  scale_color_manual(values=c("blue"))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"))

#females
ggplot(datafemale,aes(x=log10(body_length),y=log10(body_AR),color=as.factor(sex), na.rm = TRUE)) +
  geom_point(size=1)+
  #stat_smooth(method = "lm")+
  geom_abline(slope=0, intercept=0.41)+
  scale_color_manual(values=c("red"))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"))


##Antenna length - body length
m<-lm(log10(data$antenna_length)~log10(data$body_length)*as.factor(data$sex))
summary(m)
anova(m)
confint(m)

#males
ggplot(datamale,aes(x=log10(body_length),y=log10(antenna_length),color=as.factor(sex), na.rm = TRUE)) +
  geom_point(size=1)+
  stat_smooth(method = "lm")+
  geom_abline(slope=1, intercept=-0.2)+
  scale_color_manual(values=c("blue"))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"))

#females
ggplot(datafemale,aes(x=log10(body_length),y=log10(antenna_length),color=as.factor(sex), na.rm = TRUE)) +
  geom_point(size=1)+
  stat_smooth(method = "lm")+
  geom_abline(slope=1, intercept=-1.2)+
  scale_color_manual(values=c("red"))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"))


##front femur - body length
m<-lm( log10(data$front_femur)~log10(data$body_length)*as.factor(data$sex))
summary(m)
anova(m)
confint(m)

#males
ggplot(datamale,aes(x=log10(body_length),y=log10(front_femur),color=as.factor(sex), na.rm = TRUE)) +
  geom_point(size=1)+
  stat_smooth(method = "lm")+
  geom_abline(slope=1, intercept=-0.6)+
  scale_color_manual(values=c("blue"))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"))

#females
ggplot(datafemale,aes(x=log10(body_length),y=log10(front_femur),color=as.factor(sex), na.rm = TRUE)) +
  geom_point(size=1)+
  stat_smooth(method = "lm")+
  geom_abline(slope=1, intercept=-0.6)+
  scale_color_manual(values=c("red"))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"))


##wing area - body length
#female forewings
m1<-lm(log10(Total_wing_area)~log10(body_length), data=datafemale)
summary(m1)
anova(m1)
confint(m1)

ggplot(datafemale,aes(x=log10(body_length),y=log10(Total_wing_area),color=as.factor(sex), na.rm = TRUE)) +
  geom_point(size=1)+
  stat_smooth(method = "lm")+
  geom_abline(slope=2, intercept=-0.75)+
  scale_color_manual(values=c("red"))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"))

#male hindwings
m2<-lm(log10(Total_wing_area)~log10(body_length), data=datamale)
summary(m2)
anova(m2)
confint(m2)

library(ggplot2)
ggplot(datamale,aes(x=log10(body_length),y=log10(Total_wing_area),color=as.factor(sex), na.rm = TRUE)) +
  geom_point(size=1)+
  stat_smooth(method = "lm")+
  geom_abline(slope=2, intercept=-0.39)+
  scale_color_manual(values=c("blue"))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"))



##wing loading - body length (males only)
m<-lm(log10(wing_loading)~log10(body_length), data=datamale)
summary(m)
anova(m)
confint(m)

ggplot(datamale,aes(x=log10(body_length),y=log10(wing_loading),color=as.factor(sex), na.rm = TRUE)) +
  geom_point(size=1)+
  stat_smooth(method = "lm")+
  geom_abline(slope=1, intercept=-2.08)+
  scale_color_manual(values=c("blue"))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"))

##Flight muscles - body length (males only)
m<-lm(log10(data$flight_muscle_dry_mass)~log10(data$body_length))
summary(m)
anova(m)
confint(m)

ggplot(datamale,aes(x=log10(body_length),y=log10(flight_muscle_dry_mass),color=as.factor(sex), na.rm = TRUE)) +
  geom_point(size=1)+
  stat_smooth(method = "lm")+
  geom_abline(slope=3, intercept=-3.88)+
  scale_color_manual(values=c("blue"))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"))





