##################################################
##Phyllium locomotion MS - Substrate attachment###
##################################################

library(readxl)
data <- read_excel("Phyllium_attachment.xlsx")

datamale<-subset(data, data$Sex=="M")
datafemale<-subset(data, data$Sex=="F")

####Pad area allometry
##Arolium
m<-lm(log10(arolium)~log10(body_length)*Sex, data)
summary(m)
anova(m)

#males only
mm<-lm(log10(arolium)~log10(body_length), datamale)
summary(mm)
confint(mm)

#females only
mf<-lm(log10(arolium)~log10(body_length), datafemale)
summary(mf)
confint(mf)

##Euplantula
m<-lm(log10(euplantula)~log10(body_length)*Sex, data)
summary(m)
anova(m)

#males only
mm<-lm(log10(euplantula)~log10(body_length), datamale)
summary(mm)
confint(mm)

#females only
mf<-lm(log10(euplantula)~log10(body_length), datafemale)
summary(mf)
confint(mf)

##Total pad area
m<-lm(log10(projected_pad_area)~log10(body_length)*Sex, data)
summary(m)
anova(m)

#males only
mm<-lm(log10(projected_pad_area)~log10(body_length), datamale)
summary(mm)
confint(mm)

#females only
mf<-lm(log10(projected_pad_area)~log10(body_length), datafemale)
summary(mf)
confint(mf)


##Graph all pad allometries
library(ggplot2)
ggplot(data, aes(x = log10(body_length), y = log10(projected_pad_area), shape=Sex))+
  geom_point(aes(x = log10(body_length), y = log10(projected_pad_area), shape=Sex), size=2, col="purple")+
  geom_point(aes(x = log10(body_length), y = log10(arolium), shape=Sex), size=2, col="blue")+
  geom_point(aes(x = log10(body_length), y = log10(euplantula), shape=Sex), size=2, col="red")+
  geom_smooth(aes(x = log10(body_length), y = log10(euplantula), shape=Sex), size=1, col="red", method="lm")+
  geom_smooth(aes(x = log10(body_length), y = log10(projected_pad_area), shape=Sex), size=1, col="purple", method="lm")+
  geom_smooth(aes(x = log10(body_length), y = log10(arolium), shape=Sex), size=1, col="blue", method="lm")+
  geom_abline(slope=2, intercept=-3.5)+
  labs(y="log10(pad area)", x="log10(body length)")+
  theme()+
  theme_bw(base_size = 15)



#####Attachment forces
#plot
ggplot(data, aes(x = log10(body_length), y = log10(adhesion), shape=Sex))+
  geom_point(aes(x = log10(body_length), y = log10(adhesion), shape=Sex), size=2, col="darkgrey")+
  geom_point(aes(x = log10(body_length), y = log10(friction), shape=Sex), size=2, col="maroon")+
  geom_smooth(aes(x = log10(body_length), y = log10(adhesion), shape=Sex), size=1, col="darkgrey", method="lm")+
  geom_smooth(aes(x = log10(body_length), y = log10(friction), shape=Sex), size=1, col="maroon", method="lm")+
  geom_abline(slope=2, intercept=-1.3)+
  labs(y="log10(Attachment force (mN))", x="log10(body length)")+
  theme()+
  theme_bw(base_size = 15)

##Adhesive forces
m<-lm(log10(adhesion)~log10(body_length)*Sex, data)
summary(m)
anova(m)

#males only
mm<-lm(log10(adhesion)~log10(body_length), datamale)
summary(mm)
confint(mm)

#females only
mf<-lm(log10(adhesion)~log10(body_length), datafemale)
summary(mf)
confint(mf)


##Friction forces
m<-lm(log10(friction)~log10(body_length)*Sex, data)
summary(m)
anova(m)

#males only
mm<-lm(log10(friction)~log10(body_length), datamale)
summary(mm)
confint(mm)

#females only
mf<-lm(log10(friction)~log10(body_length), datafemale)
summary(mf)
confint(mf)





#####Static safety factors
#calculate SF as attachment forces divided by weight
data$SF_adh<-data$adhesion/(data$body_mass*9.81/1000)
data$SF_frct<-data$friction/(data$body_mass*9.81/1000)
datamale<-subset(data, data$Sex=="M")
datafemale<-subset(data, data$Sex=="F")

##Adhesion static SF
m<-lm(log10(SF_adh)~log10(body_mass)*data$Sex, data)
summary(m)
anova(m)

#males only
mm1<-lm(log10(SF_adh)~log10(body_mass), datamale)
summary(mm1)
confint(mm1)

#females only
mf1<-lm(log10(SF_adh)~log10(body_mass), datafemale)
summary(mf1)
confint(mf1)


##Friction static SF
m<-lm(log10(SF_frct)~log10(body_mass)*data$Sex, data)
summary(m)
anova(m)

#males only
mm2<-lm(log10(SF_frct)~log10(body_mass), datamale)
summary(mm2)
confint(mm2)

#females only
mf2<-lm(log10(SF_frct)~log10(body_mass), datafemale)
summary(mf2)
confint(mf2)



#Make a graph on log scale for x axis with power equations derived from linear models that show significant effects

s <- function(x) {
  saf<-10^(summary(mm2)$coefficients[1, 1]+(summary(mm2)$coefficients[2, 1]*log10(x)))
  return(saf)}

s1 <- function(x) {
  saf<-10^(summary(mf1)$coefficients[1, 1]+(summary(mf1)$coefficients[2, 1]*log10(x)))
  return(saf)}

s2 <- function(x) {
  saf<-10^(summary(mf2)$coefficients[1, 1]+(summary(mf2)$coefficients[2, 1]*log10(x)))
  return(saf)}

library(ggplot2)
library(scales)
ggplot(data, aes(x = body_mass, y = SF_adh, shape=Sex))+
  geom_point(aes(x = body_mass, y = SF_adh, shape=Sex), size=2, col="darkgrey")+
  geom_point(aes(x = body_mass, y = SF_frct, shape=Sex), size=2, col="maroon")+
  scale_x_log10(breaks = trans_breaks("log10", function(x) 10^x),labels = trans_format("log10", math_format(10^.x)))+
  geom_function(fun=s, col="maroon")+
  geom_function(fun=s1, col="darkgrey")+
  geom_function(fun=s2, col="maroon")+
  labs(y="Static safety factor", x="Body mass (mg)")+
  geom_abline(intercept=1, slope=0)+
  theme()+
  theme_bw(base_size = 15)





##########Calculate impact forces and SF(dynamic)
setwd("~/Documents/PhD/Manuscripts/Phyllium/Data and scripts")
library(readxl)
data <- read_excel("Phyllium_attachment.xlsx")


#We assume a male landing on a horizontal leaf. 
#The leaf will bend due to the body_mass of the animal.
#We will calculate the kinetic energy of a male based on its landing speed (estimated from its mass).

###Leaf size and stiffness vary within tropical forests so we bracketed our simulations following Higham et al. 2017.
#leaf length range (in m):
L1=0.23
L2=0.86

#Corresponding flexural stiffness (in N.m2):
EI1=0.00267
EI2=0.02848


### Calculate bending angle (theta) and tip deflection (delta). 
#linear bending because small deflection
deflection <- function(x, L, EI) {
  P=x*0.000001*9.81#convert mass in kg and calculate P in Newtons. 
  delta=(P*L^3)/(3*EI)#delta in m
  return(delta)
}

bending_angle <- function(x, L, EI) {
  P=x*0.000001*9.81#convert mass in kg and calculate P in Newtons. 
  theta=((P*L^2)/(2*EI))*180/pi#theta in degrees
  return(theta)
}

###Estimate velocity at impact from body mass (from flight experiment)
library(readxl)
d<- read_excel("flight_experiments.xlsx")#load flight experiment dataset.

#With linear mixed model
library(lme4)
m<-lmer(landing_velocity~body_mass+(1|ID), data=d)
summary(m)
library(car)
Anova(m)#significant effect of mass on landing speed
library(MuMIn)
r.squaredGLMM(m)#r squared

#plot
plot(d$body_mass, d$landing_velocity)
abline(fixef(m)[1], fixef(m)[2])

#Extract fixed effects to estimate landing speed from body mass
intercept<-fixef(m)[1]
slope<-fixef(m)[2]

#function to estimate landing speed from body mass 
landing_speed <- function(mass_mg) {
  speed<-slope*mass_mg+intercept
  return(speed)
}

###Calculate deflection of small leaf for each individual based on body mass
data<-subset(data, data$Sex=="M")#only males

data$deflection1=deflection(data$body_mass, L1, EI1)
data$deflection2=deflection(data$body_mass, L2, EI2)

data$bending_angle1=bending_angle(data$body_mass, L1, EI1)
data$bending_angle2=bending_angle(data$body_mass, L2, EI2)

####Calculate impact forces and dynamic safety factors
data$speed<-landing_speed(data$body_mass)

data$Fi1=(data$body_mass*0.000001*9.81)+((data$body_mass*0.000001*(data$speed)^2)/(2*data$deflection1))#impact forces small leaf
data$Fi2=(data$body_mass*0.000001*9.81)+((data$body_mass*0.000001*(data$speed)^2)/(2*data$deflection2))#impact forces large leaf

data$attachment_force<-data$friction*0.001#Relevant attachment force during landing in N

data$safetydyna1=data$attachment_force/data$Fi1
data$safetydyna2=data$attachment_force/data$Fi2


#Make graphs
safety_dyna<-c(data$safetydyna1, data$safetydyna2)
deflection<-c(data$deflection1*1000, data$deflection2*1000)#deflection in mm
impactforces<-c(data$Fi1*1000, data$Fi2*1000)#impact forces + body_mass in mN
masses<-c(data$body_mass, data$body_mass)
leaf<-rep(c("small leaf","large leaf"),each=length(data$safetydyna1))

dd<-data.frame(masses, safety_dyna, leaf, deflection, impactforces)

#Leaf deflection

library(ggplot2)
ggplot(dd, aes(x = masses, y = deflection, col=leaf)) +
  geom_point()+
  geom_smooth(method=lm)+
  scale_color_manual(values=c("#23D3D3", "#ff3e96"))+
  labs(y="Leaf deflection (mm)", x="Body mass (mg)")+
  theme()+
  theme_bw(base_size = 15)

#Impact forces

m1<-lm(log10(Fi1*1000)~log10(body_mass), data=data)
summary(m1)
anova(m1)
confint(m1)

m2<-lm(log10(Fi2*1000)~log10(body_mass), data=data)
summary(m2)
anova(m2)
confint(m2)

f1 <- function(x) {
  saf<-10^(summary(m1)$coefficients[1, 1]+(summary(m1)$coefficients[2, 1]*log10(x)))
  return(saf)}

f2 <- function(x) {
  saf<-10^(summary(m2)$coefficients[1, 1]+(summary(m2)$coefficients[2, 1]*log10(x)))
  return(saf)}

library(ggplot2)
ggplot(dd, aes(x = masses, y = impactforces, col=leaf)) +
  geom_point()+
  geom_function(fun=f1, col="#ff3e96")+
  geom_function(fun=f2, col="#23D3D3")+
  scale_color_manual(values=c("#23D3D3", "#ff3e96"))+
  labs(y="Impact forces + body_mass (mN)", x="Body mass (mg)")+
  theme()+
  theme_bw(base_size = 15)

m<-lm(log10(impactforces)~log10(masses)*leaf, data=dd)
summary(m)
anova(m)

#Dynamic safety factors
m1<-lm(log10(safetydyna1)~log10(body_mass), data=data)
summary(m1)
anova(m1)
confint(m1)

m2<-lm(log10(safetydyna2)~log10(body_mass), data=data)
summary(m2)
anova(m2)
confint(m2)

f1 <- function(x) {
  saf<-10^(summary(m1)$coefficients[1, 1]+(summary(m1)$coefficients[2, 1]*log10(x)))
  return(saf)}

f2 <- function(x) {
  saf<-10^(summary(m2)$coefficients[1, 1]+(summary(m2)$coefficients[2, 1]*log10(x)))
  return(saf)}

library(ggplot2)
ggplot(dd, aes(x = masses, y = safety_dyna, col=leaf)) +
  geom_point()+
  geom_function(fun=f1, col="#ff3e96")+
  geom_function(fun=f2, col="#23D3D3")+
  scale_color_manual(values=c("#23D3D3", "#ff3e96"))+
  labs(y="Dynamic safety factor", x="Body mass (mg)")+
  theme()+
  theme_bw(base_size = 15)
 

m<-lm(log10(safety_dyna)~log10(masses)*leaf, data=dd)
summary(m)
anova(m)


  







