############################################################################
##Phyllium locomotion MS - Power available and power required for flight####
############################################################################

library(readxl)
library(lme4)
data<- read_excel("flight_experiments.xlsx")

###Scaling exponent of tangential velocity of wing tip
data$amplitude_rad<-data$amplitude_stable_degrees*pi/180#convert wing beat amplitude from degrees to radians
data$wing_angular_velocity_rad<-data$wing_frequency_stable*(data$amplitude_rad*2)#calculate wing angular velocity in radian/s
data$wing_tip_velocity<-data$wing_angular_velocity_rad*(data$wing_length/1000)#calculate velocity of wing tip in m/s

#calculate scaling exponent
plot(log10(data$body_length), log10(data$wing_tip_velocity))

m0<-lmer(log10(wing_tip_velocity)~(1|ID), data=data)
m<-lmer(log10(wing_tip_velocity)~log10(body_length)+(1|ID), data=data)
summary(m)
anova(m0, m)#not significant
confint(m)


##Scaling exponent of wing disc loading
plot(log10(data$body_length), log10(data$wing_disc_loading))

m0<-lmer(log10(wing_disc_loading)~(1|ID), data=data)
m<-lmer(log10(wing_disc_loading)~log10(body_length)+(1|ID), data=data)
summary(m)
abline(fixef(m)[1], fixef(m)[2])
anova(m0, m)
confint(m)


##Scaling exponent of net required force from the wings

data<- read_excel("Phyllium_CFD.xlsx")#load CFD dataset
m<-lm(log10(data$wingforce)~log10(data$body_length))
summary(m)
anova(m)
confint(m)