
########################################################
#########Phyllium locomotion MS -- Flight trials ######
########################################################

library(readxl)
library(lme4)
data<- read_excel("flight_experiments.xlsx")#load data

##Manoeuverability
#bangle_change_slope calculated according to equation 1 (see MS)

m<-lmer(bangle_change_slope~(1|ID), data=data)#linear mixed effect models
m1<-lmer(bangle_change_slope~scale(body_mass)+(1|ID), data=data)
m2<-lmer(bangle_change_slope~scale(body_mass)+scale(wing_area)+(1|ID), data=data)
m3<-lmer(bangle_change_slope~scale(body_mass)+scale(wing_area)+scale(body_AR)+(1|ID), data=data)
summary(m3)
anova(m,m1,test="LRT")
anova(m1,m2,test="LRT")
anova(m2,m3,test="LRT")#sequentially assess the significance of each fixed effect

mm<-lmer(bangle_change_slope~(1|ID), data=data)
mm1<-lmer(bangle_change_slope~wing_loading+(1|ID), data=data)
summary(mm1)
anova(mm,mm1,test="LRT")

library(ggplot2)
ggplot(data, aes(x = wing_loading, y = bangle_change_slope))+
  geom_point(size=3) +
  geom_abline(intercept=1365.33, slope=-279.65)+
  labs(y="Rotational velocity (°/s)", x="Wing loading (N/m2)")+
  theme(axis.line = element_line(colour = "black"))+
  theme_bw(base_size = 22)

##Mean Vertical velocity
#Careful: in the dataset, positive values for vertical velocities or accelerations point downward.

library(lme4)
m<-lmer(-mean_vertical_velocity_stable~(1|ID), data=data)
m1<-lmer(-mean_vertical_velocity_stable~scale(body_mass)+(1|ID), data=data)
m2<-lmer(-mean_vertical_velocity_stable~scale(body_mass)+scale(wing_area)+(1|ID), data=data)
m3<-lmer(-mean_vertical_velocity_stable~scale(body_mass)+scale(wing_area)+scale(body_AR)+(1|ID), data=data)
summary(m3)
anova(m,m1,test="LRT")
anova(m1,m2,test="LRT")
anova(m2,m3,test="LRT")

mm<-lmer(-mean_vertical_velocity_stable~(1|ID), data=data)
mm1<-lmer(-mean_vertical_velocity_stable~wing_loading+(1|ID), data=data)
summary(mm1)
anova(mm,mm1,test="LRT")

library(ggplot2)
ggplot(data, aes(x = wing_loading, y = -mean_vertical_velocity_stable))+
  geom_point(size=3)+
  geom_abline(intercept=4.8922, slope=-1.1988)+
  labs(y="Mean vertical velocity (m/s)", x="Wing loading (N/m2)")+
  theme(axis.line = element_line(colour = "black"))+
  theme_bw(base_size = 22)

##Mean horizontal velocity
data$mean_horizontal_velocity<-data$"mean_horizontal_velocity_stable_t6-t4"
m<-lmer(mean_horizontal_velocity~(1|ID), data=data)
m1<-lmer(mean_horizontal_velocity~scale(body_mass)+(1|ID), data=data)
m2<-lmer(mean_horizontal_velocity~scale(body_mass)+scale(wing_area)+(1|ID), data=data)
m3<-lmer(mean_horizontal_velocity~scale(body_mass)+scale(wing_area)+scale(body_AR)+(1|ID), data=data)
summary(m3)
anova(m,m1,test="LRT")
anova(m1,m2,test="LRT")
anova(m2,m3,test="LRT")

mm<-lmer(mean_horizontal_velocity~(1|ID), data=data)
mm1<-lmer(mean_horizontal_velocity~wing_loading+(1|ID), data=data)
anova(mm,mm1,test="LRT")

ggplot(data, aes(x = wing_loading, y = mean_horizontal_velocity))+
  geom_point(size=3)+
  labs(y="Mean horizontal velocity (m/s)", x="Wing loading (N/m2)")+
  theme(axis.line = element_line(colour = "black"))+
  theme_bw(base_size = 22)

##Wing beat frequency
m<-lmer(wing_frequency_stable~(1|ID), data=data)
m1<-lmer(wing_frequency_stable~scale(body_mass)+(1|ID), data=data)
m2<-lmer(wing_frequency_stable~scale(body_mass)+scale(wing_area)+(1|ID), data=data)
m3<-lmer(wing_frequency_stable~scale(body_mass)+scale(wing_area)+scale(body_AR)+(1|ID), data=data)
summary(m3)
anova(m,m1,test="LRT")
anova(m1,m2,test="LRT")
anova(m2,m3,test="LRT")

mm<-lmer(wing_frequency_stable~(1|ID), data=data)
mm1<-lmer(wing_frequency_stable~wing_loading+(1|ID), data=data)
summary(mm1)
anova(mm,mm1,test="LRT")

ggplot(data, aes(x = body_mass, y = wing_frequency_stable))+
  geom_point(size=3)+
  labs(y="Wing beat frequency (Hz)", x="Body mass (mg)")+
  theme(axis.line = element_line(colour = "black"))+
  theme_bw(base_size = 22)

#Wing stroke amplitude
data$amplitude_stable<-data$"amplitude_stable_degrees"
m<-lmer(amplitude_stable~(1|ID), data=data)
m1<-lmer(amplitude_stable~scale(body_mass)+(1|ID), data=data)
m2<-lmer(amplitude_stable~scale(body_mass)+scale(wing_area)+(1|ID), data=data)
m3<-lmer(amplitude_stable~scale(body_mass)+scale(wing_area)+scale(body_AR)+(1|ID), data=data)
summary(m3)
anova(m,m1,test="LRT")
anova(m1,m2,test="LRT")
anova(m2,m3,test="LRT")

mm<-lmer(amplitude_stable~(1|ID), data=data)
mm1<-lmer(amplitude_stable~wing_loading+(1|ID), data=data)
summary(mm1)
anova(mm,mm1,test="LRT")

ggplot(data, aes(x = body_mass, y = amplitude_stable))+
  geom_point(size=3)+
  labs(y="Wing stroke amplitude (°)", x="Body mass (mg)")+
  theme(axis.line = element_line(colour = "black"))+
  theme_bw(base_size = 22)

####Resultant velocity

data$mean_velocity<-data$"mean_velocity_stable_bangle"
m<-lmer(mean_velocity~(1|ID), data=data)
m1<-lmer(mean_velocity~scale(body_mass)+(1|ID), data=data)
m2<-lmer(mean_velocity~scale(body_mass)+scale(wing_area)+(1|ID), data=data)
m3<-lmer(mean_velocity~scale(body_mass)+scale(wing_area)+scale(body_AR)+(1|ID), data=data)
summary(m3)
anova(m,m1,test="LRT")
anova(m1,m2,test="LRT")
anova(m2,m3,test="LRT")

mm<-lmer(mean_velocity~(1|ID), data=data)
mm1<-lmer(mean_velocity~wing_loading+(1|ID), data=data)
anova(mm,mm1,test="LRT")

ggplot(data, aes(x = wing_loading, y = mean_velocity))+
  geom_point(size=3)+
  labs(y="Mean resultant velocity (m/s)", x="Wing loading (N/m2)")+
  theme(axis.line = element_line(colour = "black"))+
  theme_bw(base_size = 22)

ggplot(data, aes(x = body_mass, y = mean_velocity))+
  geom_point(size=3)+
  labs(y="Mean resultant velocity (m/s)", x="Wing loading (N/m2)")+
  theme(axis.line = element_line(colour = "black"))+
  theme_bw(base_size = 22)


####Landing velocity

m<-lmer(landing_velocity~(1|ID), data=data)
m1<-lmer(landing_velocity~scale(body_mass)+(1|ID), data=data)
m2<-lmer(landing_velocity~scale(body_mass)+scale(wing_area)+(1|ID), data=data)
m3<-lmer(landing_velocity~scale(body_mass)+scale(wing_area)+scale(body_AR)+(1|ID), data=data)
summary(m3)
anova(m,m1,test="LRT")
anova(m1,m2,test="LRT")
anova(m2,m3,test="LRT")

mm<-lmer(landing_velocity~(1|ID), data=data)
mm1<-lmer(landing_velocity~wing_loading+(1|ID), data=data)
anova(mm,mm1,test="LRT")
fixef(mm1)

ggplot(data, aes(x = wing_loading, y = landing_velocity))+
  geom_point(size=3)+
  geom_abline(intercept=-1.7290360, slope=0.8572719)+
  labs(y="Landing velocity (m/s)", x="Wing loading (N/m2)")+
  theme(axis.line = element_line(colour = "black"))+
  theme_bw(base_size = 22)

mm<-lmer(landing_velocity~(1|ID), data=data)
mm2<-lmer(landing_velocity~body_mass+(1|ID), data=data)
anova(mm,mm2,test="LRT")
fixef(mm2)

ggplot(data, aes(x=body_mass, y=landing_velocity))+
  geom_point(size=3)+
  geom_abline(intercept=-0.587320737, slope=0.005400999)+
  labs(y="Landing velocity (m/s)", x="Body mass (mg)")+
  theme(axis.line = element_line(colour = "black"))+
  theme_bw(base_size = 22)

